/**
	Definitions for robot program
	Fraga 22/07/2003

**/
#ifndef ROBOT_H
#define ROBOT_H

#include <qwidget.h>
#include <qgl.h>
#include <qtimer.h>

class Robot : public QGLWidget
{
	Q_OBJECT  // must include this if you use Qt signals/slots

	#define MIN  -1.0f
	#define MAX  10.0f
	#define STEP  4.0f

public:
	Robot( QWidget *parent=0, const char *name=0 );
	QSizePolicy sizePolicy() const;
	void getPosition ( float *x, float *y ) { *x = xval; *y = yval; }
	void getSize ( int *w, int *h ) { 
		*w = windowWidth; *h = windowHeight; 
	}

public slots:
	void timerDone( void );
	void initialPosition( void ) { 
		state = 0;
		gamma = igamma;
		theta = itheta;
		updateGL( );
	}
	void startAnimation( void ) {
		timer->start(100);
	}
	void stopMove( void ) {
		timer->stop( );
 	} 

signals:
	void changePos( ); // called when mouse is moved
	void changeSize( ); // called when windows is resized
 
protected:
	void initializeGL( void );
	void resizeGL( int w, int h );
	void paintGL( void );
	// void mouseMoveEvent( QMouseEvent * );
	void mousePressEvent( QMouseEvent * );
 
 
private:
	QTimer *timer;

	int windowWidth, windowHeight;   // canvas width and height

	float yrot, xrot;  // Encene rotation

	float h, b, c;           // Parameters
    float betamax, betamin, gamma, theta; // Angles
	float igamma, fgamma, dgamma, itheta, ftheta, dtheta;
	float dmax;

	int signo;
	int xmouse, ymouse;  // Mouse pointer coordinates
	float xval, yval, height;
	int state;  // A little stated machine 
};


#endif // ROBOT_H
